# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/dreamai_ray',
                'doc_host': 'https://HamzaFarhan.github.io',
                'git_url': 'https://github.com/HamzaFarhan/dreamai_ray',
                'lib_path': 'dreamai_ray'},
  'syms': { 'dreamai_ray.imports': {},
            'dreamai_ray.mapper': { 'dreamai_ray.mapper.Callback': ('mapper.html#callback', 'dreamai_ray/mapper.py'),
                                    'dreamai_ray.mapper.Callback.after_batch': ( 'mapper.html#callback.after_batch',
                                                                                 'dreamai_ray/mapper.py'),
                                    'dreamai_ray.mapper.Callback.after_batch_rows': ( 'mapper.html#callback.after_batch_rows',
                                                                                      'dreamai_ray/mapper.py'),
                                    'dreamai_ray.mapper.Callback.before_batch': ( 'mapper.html#callback.before_batch',
                                                                                  'dreamai_ray/mapper.py'),
                                    'dreamai_ray.mapper.Callback.before_batch_rows': ( 'mapper.html#callback.before_batch_rows',
                                                                                       'dreamai_ray/mapper.py'),
                                    'dreamai_ray.mapper.Mapper': ('mapper.html#mapper', 'dreamai_ray/mapper.py'),
                                    'dreamai_ray.mapper.Mapper.__call__': ('mapper.html#mapper.__call__', 'dreamai_ray/mapper.py'),
                                    'dreamai_ray.mapper.Mapper.__init__': ('mapper.html#mapper.__init__', 'dreamai_ray/mapper.py'),
                                    'dreamai_ray.mapper.Mapper.map': ('mapper.html#mapper.map', 'dreamai_ray/mapper.py'),
                                    'dreamai_ray.mapper.cbs_after_batch': ('mapper.html#cbs_after_batch', 'dreamai_ray/mapper.py'),
                                    'dreamai_ray.mapper.cbs_after_batch_rows': ( 'mapper.html#cbs_after_batch_rows',
                                                                                 'dreamai_ray/mapper.py'),
                                    'dreamai_ray.mapper.cbs_before_batch': ('mapper.html#cbs_before_batch', 'dreamai_ray/mapper.py'),
                                    'dreamai_ray.mapper.cbs_before_batch_rows': ( 'mapper.html#cbs_before_batch_rows',
                                                                                  'dreamai_ray/mapper.py'),
                                    'dreamai_ray.mapper.msg_bs_cb': ('mapper.html#msg_bs_cb', 'dreamai_ray/mapper.py'),
                                    'dreamai_ray.mapper.msg_bs_cb.before_batch': ( 'mapper.html#msg_bs_cb.before_batch',
                                                                                   'dreamai_ray/mapper.py')},
            'dreamai_ray.pdf.app': { 'dreamai_ray.pdf.app.EmsPredictor': ('pdf/app.html#emspredictor', 'dreamai_ray/pdf/app.py'),
                                     'dreamai_ray.pdf.app.EmsPredictor.__call__': ( 'pdf/app.html#emspredictor.__call__',
                                                                                    'dreamai_ray/pdf/app.py'),
                                     'dreamai_ray.pdf.app.EmsPredictor.__init__': ( 'pdf/app.html#emspredictor.__init__',
                                                                                    'dreamai_ray/pdf/app.py'),
                                     'dreamai_ray.pdf.app.NERPredictor': ('pdf/app.html#nerpredictor', 'dreamai_ray/pdf/app.py'),
                                     'dreamai_ray.pdf.app.NERPredictor.__call__': ( 'pdf/app.html#nerpredictor.__call__',
                                                                                    'dreamai_ray/pdf/app.py'),
                                     'dreamai_ray.pdf.app.NERPredictor.__init__': ( 'pdf/app.html#nerpredictor.__init__',
                                                                                    'dreamai_ray/pdf/app.py'),
                                     'dreamai_ray.pdf.app.SegsPredictor': ('pdf/app.html#segspredictor', 'dreamai_ray/pdf/app.py'),
                                     'dreamai_ray.pdf.app.SegsPredictor.__call__': ( 'pdf/app.html#segspredictor.__call__',
                                                                                     'dreamai_ray/pdf/app.py'),
                                     'dreamai_ray.pdf.app.SegsPredictor.__init__': ( 'pdf/app.html#segspredictor.__init__',
                                                                                     'dreamai_ray/pdf/app.py'),
                                     'dreamai_ray.pdf.app.ner_pipeline': ('pdf/app.html#ner_pipeline', 'dreamai_ray/pdf/app.py'),
                                     'dreamai_ray.pdf.app.ner_pipeline_params': ( 'pdf/app.html#ner_pipeline_params',
                                                                                  'dreamai_ray/pdf/app.py'),
                                     'dreamai_ray.pdf.app.pdf_pipeline': ('pdf/app.html#pdf_pipeline', 'dreamai_ray/pdf/app.py'),
                                     'dreamai_ray.pdf.app.pdf_pipeline_params': ( 'pdf/app.html#pdf_pipeline_params',
                                                                                  'dreamai_ray/pdf/app.py')},
            'dreamai_ray.pdf.core': { 'dreamai_ray.pdf.core.cid_to_char': ('pdf/core.html#cid_to_char', 'dreamai_ray/pdf/core.py'),
                                      'dreamai_ray.pdf.core.extract_text': ('pdf/core.html#extract_text', 'dreamai_ray/pdf/core.py'),
                                      'dreamai_ray.pdf.core.extract_text_dict': ( 'pdf/core.html#extract_text_dict',
                                                                                  'dreamai_ray/pdf/core.py'),
                                      'dreamai_ray.pdf.core.extract_text_list': ( 'pdf/core.html#extract_text_list',
                                                                                  'dreamai_ray/pdf/core.py'),
                                      'dreamai_ray.pdf.core.process_line': ('pdf/core.html#process_line', 'dreamai_ray/pdf/core.py'),
                                      'dreamai_ray.pdf.core.process_text': ('pdf/core.html#process_text', 'dreamai_ray/pdf/core.py')},
            'dreamai_ray.pdf.df': { 'dreamai_ray.pdf.df.create_ner_df': ('pdf/df.html#create_ner_df', 'dreamai_ray/pdf/df.py'),
                                    'dreamai_ray.pdf.df.create_pdf_df': ('pdf/df.html#create_pdf_df', 'dreamai_ray/pdf/df.py'),
                                    'dreamai_ray.pdf.df.df_segs': ('pdf/df.html#df_segs', 'dreamai_ray/pdf/df.py'),
                                    'dreamai_ray.pdf.df.extract_df_text': ('pdf/df.html#extract_df_text', 'dreamai_ray/pdf/df.py'),
                                    'dreamai_ray.pdf.df.write_df_ems': ('pdf/df.html#write_df_ems', 'dreamai_ray/pdf/df.py'),
                                    'dreamai_ray.pdf.df.write_df_ner': ('pdf/df.html#write_df_ner', 'dreamai_ray/pdf/df.py'),
                                    'dreamai_ray.pdf.df.write_df_segs': ('pdf/df.html#write_df_segs', 'dreamai_ray/pdf/df.py')},
            'dreamai_ray.pdf.extract': { 'dreamai_ray.pdf.extract.add_other_class': ( 'pdf/extract.html#add_other_class',
                                                                                      'dreamai_ray/pdf/extract.py'),
                                         'dreamai_ray.pdf.extract.load_ems_model': ( 'pdf/extract.html#load_ems_model',
                                                                                     'dreamai_ray/pdf/extract.py'),
                                         'dreamai_ray.pdf.extract.load_segs_model': ( 'pdf/extract.html#load_segs_model',
                                                                                      'dreamai_ray/pdf/extract.py'),
                                         'dreamai_ray.pdf.extract.print_segments': ( 'pdf/extract.html#print_segments',
                                                                                     'dreamai_ray/pdf/extract.py'),
                                         'dreamai_ray.pdf.extract.text_to_ems': ( 'pdf/extract.html#text_to_ems',
                                                                                  'dreamai_ray/pdf/extract.py'),
                                         'dreamai_ray.pdf.extract.text_to_segments': ( 'pdf/extract.html#text_to_segments',
                                                                                       'dreamai_ray/pdf/extract.py'),
                                         'dreamai_ray.pdf.extract.write_embeddings': ( 'pdf/extract.html#write_embeddings',
                                                                                       'dreamai_ray/pdf/extract.py'),
                                         'dreamai_ray.pdf.extract.write_segments': ( 'pdf/extract.html#write_segments',
                                                                                     'dreamai_ray/pdf/extract.py')},
            'dreamai_ray.pdf.mappers': { 'dreamai_ray.pdf.mappers.SegsMapper': ( 'pdf/mappers.html#segsmapper',
                                                                                 'dreamai_ray/pdf/mappers.py'),
                                         'dreamai_ray.pdf.mappers.SegsMapper.__init__': ( 'pdf/mappers.html#segsmapper.__init__',
                                                                                          'dreamai_ray/pdf/mappers.py')},
            'dreamai_ray.pdf.ner': { 'dreamai_ray.pdf.ner.edu_ner': ('pdf/ner.html#edu_ner', 'dreamai_ray/pdf/ner.py'),
                                     'dreamai_ray.pdf.ner.is_valid_jner': ('pdf/ner.html#is_valid_jner', 'dreamai_ray/pdf/ner.py'),
                                     'dreamai_ray.pdf.ner.is_valid_tner': ('pdf/ner.html#is_valid_tner', 'dreamai_ray/pdf/ner.py'),
                                     'dreamai_ray.pdf.ner.job_ner': ('pdf/ner.html#job_ner', 'dreamai_ray/pdf/ner.py'),
                                     'dreamai_ray.pdf.ner.load_job_model': ('pdf/ner.html#load_job_model', 'dreamai_ray/pdf/ner.py'),
                                     'dreamai_ray.pdf.ner.load_ner_model': ('pdf/ner.html#load_ner_model', 'dreamai_ray/pdf/ner.py'),
                                     'dreamai_ray.pdf.ner.proc_ner': ('pdf/ner.html#proc_ner', 'dreamai_ray/pdf/ner.py'),
                                     'dreamai_ray.pdf.ner.work_ner': ('pdf/ner.html#work_ner', 'dreamai_ray/pdf/ner.py')},
            'dreamai_ray.redis_kv_store': {},
            'dreamai_ray.utils': { 'dreamai_ray.utils.bucket_dl': ('utils.html#bucket_dl', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.bucket_move': ('utils.html#bucket_move', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.bucket_up': ('utils.html#bucket_up', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.chain_models': ('utils.html#chain_models', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.chain_processors': ('utils.html#chain_processors', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.find_alternate_path': ('utils.html#find_alternate_path', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.get_local_path': ('utils.html#get_local_path', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.get_task_from_kv_store': ( 'utils.html#get_task_from_kv_store',
                                                                                 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.group_df_on': ('utils.html#group_df_on', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.gsutil_bucket': ('utils.html#gsutil_bucket', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.gsutil_src': ('utils.html#gsutil_src', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.handle_processors': ('utils.html#handle_processors', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.init_task_progress': ('utils.html#init_task_progress', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.is_bucket': ('utils.html#is_bucket', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.is_preprocessor': ('utils.html#is_preprocessor', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.json_file': ('utils.html#json_file', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.lit_eval': ('utils.html#lit_eval', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.repartition_ds': ('utils.html#repartition_ds', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.resolve_ds_path': ('utils.html#resolve_ds_path', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.transform_ds': ('utils.html#transform_ds', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.update_task_progress': ('utils.html#update_task_progress', 'dreamai_ray/utils.py'),
                                   'dreamai_ray.utils.write_ds': ('utils.html#write_ds', 'dreamai_ray/utils.py')}}}
